"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearStorage = void 0;
/**
 * Remove all values from Local and Session storage
 * @param except - Except key or key list
 * @returns void
 */
function clearStorage(except) {
    var _a, _b;
    if (except) {
        switch (typeof except) {
            case 'string':
                removeFromStorage(except);
                break;
            case 'object':
                var localStorageKeyList = [];
                var sessionStorageKeyList = [];
                for (var i = 0, len = localStorage.length; i < len; i++) {
                    localStorageKeyList.push((_a = localStorage.key(i)) !== null && _a !== void 0 ? _a : '');
                }
                for (var i = 0, len = sessionStorage.length; i < len; i++) {
                    sessionStorageKeyList.push((_b = sessionStorage.key(i)) !== null && _b !== void 0 ? _b : '');
                }
                localStorageKeyList
                    .filter(function (key) { return !except.includes(key); })
                    .forEach(function (key) {
                    removeItemFromStorage(localStorage, key);
                });
                sessionStorageKeyList
                    .filter(function (key) { return !except.includes(key); })
                    .forEach(function (key) {
                    removeItemFromStorage(sessionStorage, key);
                });
                break;
        }
    }
    else {
        localStorage.clear();
        sessionStorage.clear();
    }
}
exports.clearStorage = clearStorage;
function removeFromStorage(except) {
    var _a, _b;
    for (var i = 0, len = localStorage.length; i < len; i++) {
        var removeableKey = (_a = localStorage.key(i)) !== null && _a !== void 0 ? _a : '';
        if (!removeableKey.includes(except)) {
            removeItemFromStorage(localStorage, removeableKey);
        }
    }
    for (var i = 0, len = sessionStorage.length; i < len; i++) {
        var removeableKey = (_b = sessionStorage.key(i)) !== null && _b !== void 0 ? _b : '';
        if (!removeableKey.includes(except)) {
            removeItemFromStorage(sessionStorage, removeableKey);
        }
    }
}
function removeItemFromStorage(storage, key) {
    storage.removeItem(key);
}
