"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearLocalStorage = exports.removeFromLocalStorage = exports.fromLocalStorage = exports.toLocalStorage = void 0;
/**
 * Store value to Local storage
 * @param key - Stored value key
 * @param value - Stored value
 * @returns - void
 */
function toLocalStorage(key, value) {
    localStorage.setItem(key, JSON.stringify(value));
}
exports.toLocalStorage = toLocalStorage;
/**
 * Get value from Local storage
 *
 * @param key - Stored value key
 * @returns Stored value
 */
function fromLocalStorage(key) {
    return localStorage.getItem(key);
}
exports.fromLocalStorage = fromLocalStorage;
/**
 * Remove value from Local storage
 *
 * @param key - Stored value key
 * @returns void
 */
function removeFromLocalStorage(key) {
    localStorage.removeItem(key);
}
exports.removeFromLocalStorage = removeFromLocalStorage;
/**
 * Remove all values from Local storage
 *
 * @param except - Except key or key list
 * @returns void
 */
function clearLocalStorage(except) {
    var _a;
    if (except) {
        switch (typeof except) {
            case 'string':
                removeFromStorage(except);
                break;
            case 'object':
                var localStorageKeyList = [];
                for (var i = 0, len = localStorage.length; i < len; i++) {
                    localStorageKeyList.push((_a = localStorage.key(i)) !== null && _a !== void 0 ? _a : '');
                }
                localStorageKeyList
                    .filter(function (key) { return !except.includes(key); })
                    .forEach(function (key) {
                    localStorage.removeItem(key);
                });
                break;
        }
    }
    else {
        localStorage.clear();
    }
}
exports.clearLocalStorage = clearLocalStorage;
function removeFromStorage(except) {
    var _a;
    for (var i = 0, len = localStorage.length; i < len; i++) {
        var removeableKey = (_a = localStorage.key(i)) !== null && _a !== void 0 ? _a : '';
        if (!removeableKey.includes(except)) {
            localStorage.removeItem(removeableKey);
        }
    }
}
