"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearSessionStorage = exports.removeFromSessionStorage = exports.fromSessionStorage = exports.toSessionStorage = void 0;
/**
 * Store value to Session storage
 *
 * @param key - Stored value key
 * @param value - Stored value
 * @returns void
 */
function toSessionStorage(key, value) {
    sessionStorage.setItem(key, JSON.stringify(value));
}
exports.toSessionStorage = toSessionStorage;
/**
 * Get value from Session storage
 *
 * @param key - Stored value key
 * @returns Stored value
 */
function fromSessionStorage(key) {
    return sessionStorage.getItem(key);
}
exports.fromSessionStorage = fromSessionStorage;
/**
 * Remove value from Session storage
 *
 * @param key - Stored value key
 * @returns void
 */
function removeFromSessionStorage(key) {
    sessionStorage.removeItem(key);
}
exports.removeFromSessionStorage = removeFromSessionStorage;
/**
 * Remove all values from Session storage
 *
 * @param except - Except key or key list
 * @returns void
 */
function clearSessionStorage(except) {
    var _a;
    if (except) {
        switch (typeof except) {
            case 'string':
                removeFromStorage(except);
                break;
            case 'object':
                var sessionStorageKeyList = [];
                for (var i = 0, len = sessionStorage.length; i < len; i++) {
                    sessionStorageKeyList.push((_a = sessionStorage.key(i)) !== null && _a !== void 0 ? _a : '');
                }
                sessionStorageKeyList
                    .filter(function (key) { return !except.includes(key); })
                    .forEach(function (key) {
                    sessionStorage.removeItem(key);
                });
                break;
        }
    }
    else {
        sessionStorage.clear();
    }
}
exports.clearSessionStorage = clearSessionStorage;
function removeFromStorage(except) {
    var _a;
    for (var i = 0, len = sessionStorage.length; i < len; i++) {
        var removeableKey = (_a = sessionStorage.key(i)) !== null && _a !== void 0 ? _a : '';
        if (!removeableKey.includes(except)) {
            sessionStorage.removeItem(removeableKey);
        }
    }
}
